@@ -21,12 +21,20 @@ class SplitViewMagic(Magics):
     @magic_arguments.argument(
         "--height",
         "-h",
-        default="300",
+        default="auto",
         help=(
             "The widget's height. The width will be adjusted automatically. \
              If height is `auto`, the vertical resolution of the first image is used."
         ),
     )
+    @magic_arguments.argument(
+        "--config",
+        "-c",
+        default="{}",
+        help=(
+            "The compare view config as described here: https://github.com/Octoframes/compare_view"
+        ),
+    )
     @cell_magic
     def splity(self, line, cell):
         """Saves the png image and calls the splitview canvas"""
@@ -47,22 +55,21 @@ class SplitViewMagic(Magics):
         # get the parameters that configure the widget
         args = magic_arguments.parse_argstring(SplitViewMagic.splity, line)
 
-        slider_position = args.position
-        widget_height = args.height
+        height = args.height
 
-        if widget_height == "auto":
+        if height == "auto":
             imgdata = b64decode(out_images_base64[0])
             # maybe possible without the PIL dependency?
             im = Image.open(io.BytesIO(imgdata))
-            widget_height = im.size[1]
+            height = im.size[1]
 
         image_data_urls = [f"data:image/jpeg;base64,{base64.strip()}" for base64 in out_images_base64]
 
         # every juxtapose html node needs unique id
         inject_split(
-            image_data_urls=image_data_urls,
-            slider_position=slider_position,
-            wrapper_height=int(widget_height)+4,
-            height=int(widget_height),
+            image_urls=image_data_urls,
+            height=height,
+            # as JSON object
+            config=args.config,
         )
 
